@@ -84,17 +84,19 @@ class InterfaceMQTT:
         self.__setup_sensor(client, sensor_topic_head, "tags_filter", "mdi:image-search", available_topic)
         self.__setup_sensor(client, sensor_topic_head, "image_counter", "mdi:camera-burst", available_topic)
         self.__setup_sensor(client, sensor_topic_head, "image", "mdi:file-image", available_topic, has_attributes=True)
-        
 
         ## numbers
         self.__setup_number(client, number_topic_head, "brightness", 0.0, 1.0, 0.1, "mdi:brightness-6", available_topic)
         self.__setup_number(client, number_topic_head, "time_delay", 1, 400, 1, "mdi:image-plus", available_topic)
         self.__setup_number(client, number_topic_head, "fade_time", 1, 50, 1,"mdi:image-size-select-large", available_topic)
+        self.__setup_number(client, number_topic_head, "matting_images", 0.0, 1.0, 0.01, "mdi:image-frame", available_topic)
 
         ## selects
         _, dir_list = self.__controller.get_directory_list()
         dir_list.sort()
-        self.__setup_select(client, select_topic_head, "directory", dir_list, "mdi:folder-multiple-image", available_topic)
+        self.__setup_select(client, select_topic_head, "directory", dir_list, "mdi:folder-multiple-image", available_topic, init=True)
+        command_topic = self.__device_id + "/directory"
+        client.subscribe(command_topic, qos=0)
 
         ## switches
         self.__setup_switch(client, switch_topic_head, "_text_refresh", "mdi:refresh", available_topic)
@@ -148,7 +150,7 @@ class InterfaceMQTT:
                                      "dev":{"ids":[self.__device_id]}})
         client.publish(config_topic, config_payload, qos=0, retain=True)
         client.subscribe(self.__device_id + "/" + topic, qos=0)
-    
+
     def __setup_number(self, client, number_topic_head, topic, min, max, step, icon, available_topic):
         config_topic = number_topic_head + "_" + topic + "/config"
         command_topic = self.__device_id + "/" + topic
@@ -168,12 +170,12 @@ class InterfaceMQTT:
         client.publish(config_topic, config_payload, qos=0, retain=True)
         client.subscribe(command_topic, qos=0)
 
-    def __setup_select(self, client, select_topic_head, topic, options, icon, available_topic):
+    def __setup_select(self, client, select_topic_head, topic, options, icon, available_topic, init=False):
         config_topic = select_topic_head + "_" + topic + "/config"
         command_topic = self.__device_id + "/" + topic
         state_topic = "homeassistant/sensor/" + self.__device_id + "/state"
         name = self.__device_id + "_" + topic
-        
+
         config_payload = json.dumps({"name": name,
                                     "icon": icon,
                                     "options": options,
@@ -184,7 +186,8 @@ class InterfaceMQTT:
                                     "uniq_id": name,
                                     "dev":{"ids":[self.__device_id]}})
         client.publish(config_topic, config_payload, qos=0, retain=True)
-        client.subscribe(command_topic, qos=0)
+        if init:
+            client.subscribe(command_topic, qos=0)
 
     def __setup_switch(self, client, switch_topic_head, topic, icon,
                        available_topic, is_on=False):
@@ -353,6 +356,10 @@ class InterfaceMQTT:
         elif message.topic == self.__device_id + "/brightness":
             self.__logger.info("Recieved brightness: %s", msg)
             self.__controller.brightness = float(msg)
+        # matting_images
+        elif message.topic == self.__device_id + "/matting_images":
+            self.__logger.info("Received matting_images: %s", msg)
+            self.__controller.matting_images = float(msg)
         # location filter
         elif message.topic == self.__device_id + "/location_filter":
             self.__logger.info("Recieved location filter: %s", msg)
@@ -378,7 +385,7 @@ class InterfaceMQTT:
 
         sensor_state_payload = {}
 
-        ## sensor  
+        ## sensor
         # directory sensor
         actual_dir, dir_list = self.__controller.get_directory_list()
         sensor_state_payload["directory"] = actual_dir
@@ -403,6 +410,8 @@ class InterfaceMQTT:
         sensor_state_payload["fade_time"] = self.__controller.fade_time
         # brightness
         sensor_state_payload["brightness"] = self.__controller.brightness
+        # matting_images
+        sensor_state_payload["matting_images"] = self.__controller.matting_images
 
         # send last will and testament
         available_topic = switch_topic_head + "/available"
@@ -413,7 +422,7 @@ class InterfaceMQTT:
         self.__logger.debug("Send image attributes: %s", image_attr)
         self.__client.publish(attributes_topic, json.dumps(image_attr), qos=0, retain=False)
         dir_list.sort()
-        self.__setup_select(self.__client, select_topic_head, "directory", dir_list, "mdi:folder-multiple-image", available_topic)
+        self.__setup_select(self.__client, select_topic_head, "directory", dir_list, "mdi:folder-multiple-image", available_topic, init=False)
 
         self.__logger.info("Send sensor state: %s", sensor_state_payload)
         self.__client.publish(sensor_state_topic, json.dumps(sensor_state_payload), qos=0, retain=False)
